@@ -29,20 +29,20 @@ _pkg_config = {
     'android_abi':        '',
     'arch':               '',
     'default_bin_dir':    '/usr/bin',
-    'default_mod_dir':    '/usr/lib/python3.9/site-packages',
+    'default_mod_dir':    '/usr/lib/python3.10/site-packages',
     'default_sip_dir':    '/usr/share/sip',
     'deployment_target':  '',
     'platform':           'linux-g++',
-    'py_conf_inc_dir':    '/usr/include/python3.9',
-    'py_inc_dir':         '/usr/include/python3.9',
-    'py_lib_dir':         '/usr/lib/python3.9/config',
-    'py_version':         0x030902,
+    'py_conf_inc_dir':    '/usr/include/python3.10',
+    'py_inc_dir':         '/usr/include/python3.10',
+    'py_lib_dir':         '/usr/lib/python3.10/config',
+    'py_version':         0x030a01,
     'qt_framework':       0,
     'sip_bin':            '/usr/bin/sip',
-    'sip_config_args':    'CFLAGS=-march=armv8-a -O2 -pipe -fno-plt LFLAGS=-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now',
-    'sip_inc_dir':        '/usr/include/python3.9',
-    'sip_module_dir':     '/usr/lib/python3.9/site-packages',
-    'sip_root_dir':       '/usr/lib/python3.9/site-packages',
+    'sip_config_args':    'CFLAGS=-march=armv8-a -O2 -pipe -fstack-protector-strong -fno-plt LFLAGS=-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now',
+    'sip_inc_dir':        '/usr/include/python3.10',
+    'sip_module_dir':     '/usr/lib/python3.10/site-packages',
+    'sip_root_dir':       '/usr/lib/python3.10/site-packages',
     'sip_version':        0x041319,
     'sip_version_str':    '4.19.25',
     'universal':          ''
@@ -52,7 +52,7 @@ _default_macros = {
     'AIX_SHLIB':                '',
     'AR':                       'ar cqs',
     'CC':                       'gcc',
-    'CFLAGS':                   '-march=armv8-a -O2 -pipe -fno-plt',
+    'CFLAGS':                   '-march=armv8-a -O2 -pipe -fstack-protector-strong -fno-plt',
     'CFLAGS_APP':               '',
     'CFLAGS_CONSOLE':           '',
     'CFLAGS_DEBUG':             '-g',
